@@ -34,10 +34,10 @@ def compute_coefficients(data, h_ref, psd, freqs, f_bins, f_bins_center):
     self_prod = np.array(h_ref*h_ref.conj())
     for i in range(len(f_bins)-1):
         f_index = np.where((freqs >= f_bins[i]) & (freqs < f_bins[i+1]))[0]
-        A0_array.append(4*np.sum(data_prod[f_index]/psd[f_index]*df))
-        A1_array.append(4*np.sum(data_prod[f_index]/psd[f_index]*df*(freqs[f_index]-f_bins_center[i])))
-        B0_array.append(4*np.sum(self_prod[f_index]/psd[f_index]*df))
-        B1_array.append(4*np.sum(self_prod[f_index]/psd[f_index]*df*(freqs[f_index]-f_bins_center[i])))
+        A0_array.append(4*np.sum(data_prod[f_index]/psd[f_index])*df)
+        A1_array.append(4*np.sum(data_prod[f_index]/psd[f_index]*(freqs[f_index]-f_bins_center[i]))*df)
+        B0_array.append(4*np.sum(self_prod[f_index]/psd[f_index])*df)
+        B1_array.append(4*np.sum(self_prod[f_index]/psd[f_index]*(freqs[f_index]-f_bins_center[i]))*df)
 
     A0_array = jnp.array(A0_array)
     A1_array = jnp.array(A1_array)
@@ -70,7 +70,7 @@ def make_heterodyne_likelihood(data, h_function, ref_theta, psd, freqs, n_bins=1
 def make_heterodyne_likelihood_mutliple_detector(data_list, psd_list, respose_list, h_function, ref_theta, freqs, gmst, epoch, f_ref, n_bins=101):
 
     num_detector = len(data_list)
-    theta_waveform = ref_theta[:8]
+    theta_waveform = ref_theta
     theta_waveform = theta_waveform.at[5].set(0)
     raw_hp, raw_hc = h_function(freqs, theta_waveform, f_ref)
     index = jnp.where((jnp.abs(raw_hc)+jnp.abs(raw_hp)) > 0)
@@ -107,7 +107,7 @@ def make_heterodyne_likelihood_mutliple_detector(data_list, psd_list, respose_li
         
         
     def hetrodyne_likelihood(params):
-        theta_waveform = params[:8]
+        theta_waveform = params
         theta_waveform = theta_waveform.at[5].set(0)
         ra, dec = params[9], params[10]
 
@@ -129,4 +129,4 @@ def make_heterodyne_likelihood_mutliple_detector(data_list, psd_list, respose_li
         
         return output_SNR
     
-    return hetrodyne_likelihood
\ No newline at end of file
+    return hetrodyne_likelihood
